@@ -49,7 +49,7 @@ composition_right_horizontal_day_button(WDB *new_day_button){
     /* background */
     memset(buffer, 0, sizeof(buffer));
     snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_RIGHT_HORIZONTAL_BACKGROUND);
- //   new_day_button->background = gtk_image_new_from_file (buffer);
+//    new_day_button->background = gtk_image_new_from_file (buffer);
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
@@ -60,7 +60,7 @@ composition_right_horizontal_day_button(WDB *new_day_button){
         gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
     if (new_day_button->wind_text)
         gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
-
+/*
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
 
@@ -99,7 +99,7 @@ composition_right_horizontal_day_button(WDB *new_day_button){
         set_font(temperature, PRESET_TEMPERATURE_FONT, -1);
       gtk_widget_set_size_request(temperature, 66, 60);
     }
-
+*/
     if (day)
             gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0, 60+37+10);
     if (temperature)
@@ -142,7 +142,7 @@ composition_central_horizontal_day_button(WDB *new_day_button)
         gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
     if (new_day_button->wind_text)
         gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
-
+/*
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
 
@@ -186,6 +186,7 @@ composition_central_horizontal_day_button(WDB *new_day_button)
             gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+2, 60+37+9+30);
 
     gtk_widget_destroy(new_day_button->label);
+    */
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -475,6 +476,7 @@ composition_now(WDB *new_day_button, gint layout)
 #endif
 
     /* create day box to contain icon, label and wind image */
+    /*
     memset(buffer, 0, sizeof(buffer));
     switch (layout){
         case PRESET_NOW_PLUS_THREE_V:
@@ -505,6 +507,7 @@ composition_now(WDB *new_day_button, gint layout)
             gtk_widget_set_size_request(new_day_button->box, xoffset+140+1, 37+15+106);
             break;
     }
+    */
 //    new_day_button->background = gtk_image_new_from_file (buffer);
 /* Packing all to the box */
     if (new_day_button->background)
@@ -588,7 +591,9 @@ next_station_preset_now(gint layout)
         g_signal_connect(station_name_btn, "button-press-event",
                     G_CALLBACK(change_station_next), NULL);
     }
+    
     /* Create station name */
+#if 0
     station_text = gtk_label_new(NULL);
     if(app->config->current_station_id){
         memset(buffer, 0, sizeof(buffer));
@@ -614,7 +619,7 @@ next_station_preset_now(gint layout)
         station_text = NULL;
         shadow_station_text = NULL;
     }
-
+#endif
     if (station_name_btn)
         gtk_fixed_put(GTK_FIXED(widget), station_name_btn, x_offset, 0);
     if (shadow_station_text)
@@ -639,6 +644,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
+
     /* create day label */
     new_day_button->label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(new_day_button->label), text);
@@ -650,7 +656,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         set_font(new_day_button->label, PRESET_BIG_FONT, -1);
     gtk_widget_set_size_request(new_day_button->label, 140, 52);
 
-
+#if 0
     /* create wind text */
     new_day_button->wind_text = gtk_label_new(NULL);
     memset(buffer, 0, sizeof(buffer));
@@ -663,7 +669,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
     /* Set font size for label */
     set_font(new_day_button->wind_text, PRESET_WIND_FONT, -1);
     gtk_widget_set_size_request(new_day_button->wind_text, 30, 30);
-
+#endif
    /* create day icon buffer */
     icon_buffer =
           gdk_pixbuf_new_from_file_at_size(icon,
@@ -675,7 +681,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         new_day_button->icon_image = create_icon_widget(icon_buffer, icon, PRESET_NORMAL_IMAGE_SIZE, &app->clutter_objects_in_main_form);
     else
         new_day_button->icon_image = NULL;
-
+#if 0
     memset(buffer, 0, sizeof(buffer));
     switch (wind_direction){
        case TO_SOUTH:
@@ -723,7 +729,6 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
            begin_of_string = strstr(buffer,".png"); 
            snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
         }
-
         /* create day icon buffer */
         icon_buffer =
           gdk_pixbuf_new_from_file(buffer,
@@ -736,6 +741,7 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         else
             new_day_button->wind = NULL;
     }
+#endif
     new_day_button->box  = gtk_fixed_new();
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
@@ -753,6 +759,7 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
+#if 0
     /* create day label */
     new_day_button->label = gtk_label_new(NULL);
     gtk_label_set_markup(GTK_LABEL(new_day_button->label), text);
@@ -763,7 +770,6 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
     else
         set_font(new_day_button->label, PRESET_BIG_FONT, -1);
     gtk_widget_set_size_request(new_day_button->label, 140, 52);
-
 /*        gtk_widget_set_name(new_day_button->label, "day_label");*/
     /* create shadow of day label */
     /* check for memcpy operation */
@@ -795,7 +801,7 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
     /* Set font size for label */
     set_font(new_day_button->wind_text, PRESET_WIND_FONT, -1);
     gtk_widget_set_size_request(new_day_button->wind_text, 30, 30);
-
+#endif
    /* create day icon buffer */
     icon_buffer =
           gdk_pixbuf_new_from_file_at_size(icon,
@@ -858,7 +864,7 @@ fill_weather_day_button_preset_now(WDB *new_day_button, const char *text, const
            snprintf(begin_of_string, sizeof(buffer) - strlen(buffer) - 1, "%s","_warning.png");
 //           new_day_button->wind = gtk_image_new_from_file (buffer);
         }
-*/
+*/	
     }
     new_day_button->box  = gtk_fixed_new();
 }
